@@ -15,3 +15,20 @@ from .statsig_server import StatsigServer
 from .statsig_user import StatsigUser
 from .utils import HashingAlgorithm
 from .version import __version__
+from .stream_decompressor import StreamDecompressor
+
+__all__ = [
+    "DynamicConfig",
+    "FeatureGate",
+    "HashingAlgorithm",
+    "IDataStore",
+    "Layer",
+    "LogLevel",
+    "OutputLogger",
+    "StatsigEnvironmentTier",
+    "StatsigEvent",
+    "StatsigOptions",
+    "StatsigServer",
+    "StatsigUser",
+    "__version__",
+]
