@@ -1,7 +1,7 @@
 class Const:
     SUPPORTED_CONDITION_TYPES = ['public', 'fail_gate', 'pass_gate', 'ip_based', 'ua_based', 'user_field',
                                  'environment_field', 'current_time', 'user_bucket', 'unit_id', 'multi_pass_gate',
-                                 'multi_fail_gate']
+                                 'multi_fail_gate', 'target_app']
 
     SUPPORTED_OPERATORS = ['gt', 'gte', 'lt', 'lte',
                            'version_gt', 'version_gte', 'version_lt', 'version_lte',
