@@ -1,17 +1,19 @@
 import json
 import threading
 import time
-from typing import Optional, Callable, List, Any, Tuple
+from typing import Optional, Callable, List, Tuple
 
 from . import globals
 from .diagnostics import Diagnostics, Marker, Context, Key
-from .evaluation_details import EvaluationReason
+from .evaluation_details import DataSource
+from .http_worker import RequestResult
 from .interface_data_store import IDataStore
 from .interface_network import IStreamingListeners
+from .statsig_context import InitContext
 from .statsig_error_boundary import _StatsigErrorBoundary
 from .statsig_errors import StatsigValueError, StatsigNameError
 from .statsig_network import _StatsigNetwork
-from .statsig_options import DataSource, StatsigOptions
+from .statsig_options import StatsigOptions
 from .thread_util import spawn_background_thread, THREAD_JOIN_TIMEOUT
 from .utils import djb2_hash
 
@@ -32,6 +34,7 @@ class SpecUpdater:
             error_boundary: _StatsigErrorBoundary,
             statsig_metadata: dict,
             shutdown_event: threading.Event,
+            context: InitContext
     ):
         self._shutdown_event = shutdown_event
         self._sync_failure_count = 0
@@ -56,10 +59,12 @@ class SpecUpdater:
         self.dcs_listener: Optional[Callable] = None
         self.id_lists_listener: Optional[Callable] = None
         self.data_adapter = data_adapter
+        self.context = context
 
     def get_config_spec(self, source: DataSource, for_initialize=False):
         try:
-            self._log_process(f"Loading specs from {source.value}...")
+            self._log_process(f"Loading specs from {source.value}...",
+                              "Initialize" if for_initialize else "Config Sync")
             init_timeout = None
             if for_initialize:
                 init_timeout = self._options.init_timeout
@@ -84,16 +89,15 @@ class SpecUpdater:
         self.id_lists_listener = listener
 
     def register_process_dcs_listener(self, listener: Callable):
-        def dcs_listener_with_lock(spec_json, reason: EvaluationReason) -> bool:
+        def dcs_listener_with_lock(spec_json, source: DataSource) -> bool:
             with self._dcs_process_lock:
-                return listener(spec_json, reason)
+                return listener(spec_json, source)
 
         self.dcs_listener = dcs_listener_with_lock
 
     def load_config_specs_from_storage_adapter(self) -> bool:
         def load():
             try:
-                self._log_process("Loading specs from adapter")
                 if self._options.data_store is None:
                     return False
 
@@ -118,7 +122,7 @@ class SpecUpdater:
                 self._log_process("Done loading specs")
                 _, parse_success = False, False
                 if self.dcs_listener is not None:
-                    _, parse_success = self.dcs_listener(cache, EvaluationReason.data_adapter)
+                    _, parse_success = self.dcs_listener(cache, DataSource.DATASTORE)
                 self._diagnostics.add_marker(
                     Marker()
                     .data_store_config_specs()
@@ -147,7 +151,7 @@ class SpecUpdater:
             self._sync_failure_count += 1
         return success
 
-    def _on_dcs_complete(self, specs: dict, error: Optional[Exception]):
+    def _on_dcs_complete(self, data_source: DataSource, specs: Optional[dict], error: Optional[Exception]):
         def process() -> Tuple[bool, Optional[Exception]]:
             if error is not None:
                 return False, error
@@ -160,9 +164,9 @@ class SpecUpdater:
                     Marker().download_config_specs().process().start()
                 )
                 self._log_process("Done loading specs")
-                has_update, parse_success = False, False
+                has_update, parse_success = False, False  # parce success can be true even if there is no update
                 if self.dcs_listener is not None:
-                    has_update, parse_success = self.dcs_listener(specs, EvaluationReason.network)
+                    has_update, parse_success = self.dcs_listener(specs, data_source)
                 if has_update:
                     self._save_to_storage_adapter(specs)
                 return parse_success, None
@@ -180,7 +184,7 @@ class SpecUpdater:
 
         parse_success, error = process()
         if parse_success is False:
-            self._sync_failure_count += 1
+            self._sync_failure_count += 1  # increment sync failure to trigger fallback behavior
 
     def _log_process(self, msg, process=None):
         if process is None:
@@ -221,7 +225,7 @@ class SpecUpdater:
             if specs is None or not self.is_specs_json_valid(specs):
                 return
             if self.dcs_listener is not None:
-                _, success = self.dcs_listener(specs, EvaluationReason.bootstrap)
+                _, success = self.dcs_listener(specs, DataSource.BOOTSTRAP)
 
         except ValueError:
             # JSON decoding failed, just let background thread update rulesets
@@ -250,7 +254,7 @@ class SpecUpdater:
                 init_timeout = self._options.init_timeout
 
             self._network.get_id_lists(on_complete, False, init_timeout)
-            if result[0] is False:
+            if result[0] is False and self._options.fallback_to_statsig_api:
                 self._network.get_id_lists_fallback(on_complete, False, init_timeout)
 
         except Exception as e:
@@ -261,7 +265,7 @@ class SpecUpdater:
     def download_single_id_list(
             self, url, list_name, local_list, all_lists, start_index
     ):
-        def on_complete(resp: Any):
+        def on_complete(resp: RequestResult):
             if resp is None:
                 return
             threw_error = False
@@ -269,7 +273,7 @@ class SpecUpdater:
                 self._diagnostics.add_marker(
                     Marker().get_id_list().process().start({"url": url})
                 )
-                content_length_str = resp.headers.get("content-length")
+                content_length_str = resp.headers.get("content-length") if resp.headers else None
                 if content_length_str is None:
                     raise StatsigValueError("Content length invalid.")
                 content_length = int(content_length_str)
@@ -327,7 +331,7 @@ class SpecUpdater:
                 if self.last_update_time > lcut:
                     return
                 if self.dcs_listener is not None:
-                    self.dcs_listener(specs, EvaluationReason.network)
+                    self.dcs_listener(specs, DataSource.NETWORK)
 
             def on_error_dcs(e: Exception):
                 # pylint: disable=unused-argument
@@ -379,17 +383,27 @@ class SpecUpdater:
                 if self._enforce_sync_fallback_threshold_in_ms is not None and time_elapsed > self._enforce_sync_fallback_threshold_in_ms:
                     outof_sync = True
                 if prev_failure_count == self._sync_failure_count and not outof_sync:
-                    globals.logger.log_process("Config Sync", f"Syncing config values with {strategy.value} successful")
+                    globals.logger.log_process(
+                        "Config Sync",
+                        f"Syncing config values with {strategy.value}"
+                        + (f"[{self.context.source_api}]" if self.context.source_api else "")
+                        + " successful"
+                    )
                     break
                 if i < len(self._config_sync_strategies) - 1:
                     globals.logger.log_process(
                         "Config Sync",
-                        f"Syncing config values failed with {strategy.value}, falling back to next available configured config sync method"
+                        f"Syncing config values failed with {strategy.value}"
+                        + (f"[{self.context.source_api}]" if self.context.source_api else "")
+                        + ", falling back to next available configured config sync method"
                     )
+
                 else:
                     globals.logger.log_process(
                         "Config Sync",
-                        f"Syncing config values failed with {strategy.value}. No more strategies left. The next sync will be in {interval} seconds."
+                        f"Syncing config values failed with {strategy.value}"
+                        + (f"[{self.context.source_api}]" if self.context.source_api else "")
+                        + f". No more strategies left. The next sync will be in {interval} seconds."
                     )
 
         self._background_download_configs = spawn_background_thread(
