@@ -1,6 +1,8 @@
 from enum import Enum
 from typing import List, Optional, Union, Callable, Dict, Any
 
+from .utils import JSONValue, to_raw_dict_or_none
+
 from .dynamic_config import DynamicConfig
 from .evaluation_details import DataSource
 from .feature_gate import FeatureGate
@@ -113,6 +115,9 @@ class StatsigOptions:
             sdk_error_callback: Optional[Callable[[str, Exception], None]] = None,
             events_flushed_callback: Optional[
                 Callable[[bool, List[Dict], Optional[int], Optional[Exception]], None]] = None,
+            global_custom_fields: Optional[Dict[str, JSONValue]] = None,
+            disable_ua_parser: bool = False,
+            disable_country_lookup: bool = False,
     ):
         self.data_store = data_store
         self._environment: Union[None, dict] = None
@@ -163,6 +168,9 @@ class StatsigOptions:
         self.sdk_error_callback = sdk_error_callback
         self.events_flushed_callback = events_flushed_callback
         self._logging_copy: Dict[str, Any] = {}
+        self.global_custom_fields = global_custom_fields
+        self.disable_ua_parser = disable_ua_parser
+        self.disable_country_lookup = disable_country_lookup
         self._set_logging_copy()
         self._attributes_changed = False
 
@@ -244,5 +252,11 @@ class StatsigOptions:
             logging_copy["config_sync_sources"] = "SET"
         if self.sdk_error_callback:
             logging_copy["sdk_error_callback"] = "SET"
+        if self.global_custom_fields:
+            logging_copy["global_custom_fields"] = to_raw_dict_or_none(self.global_custom_fields)
+        if self.disable_ua_parser:
+            logging_copy["disable_ua_parser"] = self.disable_ua_parser
+        if self.disable_country_lookup:
+            logging_copy["disable_country_lookup"] = self.disable_country_lookup
         self._logging_copy = logging_copy
         self._attributes_changed = False
